@@ -107,7 +107,7 @@ except ImportError:
                           " install ordereddict 1.1 from pypi for python2.6")
 
 __pkgname__ = 'python-crontab'
-__version__ = '2.3.5'
+__version__ = '2.3.7'
 
 ITEMREX = re.compile(r'^\s*([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)\s+([^@#\s]+)'
                      r'\s+([^@#\s]+)\s+([^\n]*?)(\s+#\s*([^\n]*)|$)')
@@ -387,7 +387,7 @@ class CronTab(object):
         for line in self.lines:
             if isinstance(line, (unicode, str)):
                 if line.strip().startswith('#') or not line.strip():
-                    crons.append(line)
+                    crons.append(line.strip())
                 elif not errors:
                     crons.append('# DISABLED LINE\n# ' + line)
                 else:
@@ -395,7 +395,7 @@ class CronTab(object):
             elif isinstance(line, CronItem):
                 if not line.is_valid() and not errors:
                     line.enabled = False
-                crons.append(unicode(line))
+                crons.append(unicode(line).strip())
 
         # Environment variables are attached to cron lines so order will
         # always work no matter how you add lines in the middle of the stack.
@@ -611,8 +611,14 @@ class CronItem(object):
         self.comment = result[0][-1]
         if self.cron.user is False:
             # Special flag to look for per-command user
-            (self.user, cmd) = (result[0][-3] + ' ').split(' ', 1)
-            self.set_command(cmd)
+            ret = result[0][-3].split(None, 1)
+            self.set_command(ret[-1])
+            if len(ret) == 2:
+                self.user = ret[0]
+            else:
+                self.valid = False
+                self.enabled = False
+                LOG.error(str("Missing user or command in system cron line."))
         else:
             self.set_command(result[0][-3])
         try:
@@ -949,8 +955,10 @@ class CronSlices(list):
         "Return just the first part of a cron job (the numbers or special)"
         slices = self.clean_render()
         if self.special:
-            return self.special
-        elif not SYSTEMV:
+            if self.special == '@reboot' or \
+                    SPECIALS[self.special.strip('@')] == slices:
+                return self.special
+        if not SYSTEMV:
             for (name, value) in SPECIALS.items():
                 if value == slices and name not in SPECIAL_IGNORE:
                     return "@%s" % name
