@@ -131,7 +131,7 @@ class UseTestCase(unittest.TestCase):
 
     def test_08_cronitem(self):
         """CronItem Standalone"""
-        item = crontab.CronItem(line='noline')
+        item = crontab.CronItem.from_line('noline')
         self.assertTrue(item.is_enabled())
         with self.assertRaises(UnboundLocalError):
             item.delete()
@@ -203,6 +203,15 @@ class UseTestCase(unittest.TestCase):
         with Attribute(crontab, 'ZERO_PAD', True):
             self.assertEqual(str(cron), '02 03-05 02,04 */2 01 cmd\n')
 
+    def test_08_reset_after_daily(self):
+        """Can jobs be rescheduled after midnight"""
+        cron = crontab.CronTab(tab="@daily cmd")
+        job = cron[0]
+        self.assertEqual(str(job), '@daily cmd')
+        job.minute.on(5)
+        job.hour.on(1)
+        self.assertEqual(str(job), '5 1 * * * cmd')
+
     def tearDown(self):
         for filename in self.filenames:
             if os.path.exists(filename):
